==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/update/index.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>Update Passwords</title>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<meta name="keywords" content="" />
<meta name="description" content="" />
<link href="../assets/css/styles.css" rel="stylesheet" type="text/css" media="screen" />
<link href="../assets/css/menu.css" media="screen" rel="stylesheet" type="text/css" />
<link href="../assets/css/buttons.css" rel="stylesheet" type="text/css">
<link href="update.css" media="screen" rel="stylesheet" type="text/css" />

<script src="../assets/js/jquery-min.js" type="text/javascript"></script>
<script src="../assets/js/jquery.noty.packaged.js" type="text/javascript"></script>
<script src="update.js" type="text/javascript"></script>

</head>
<body>
<div id="content">

<div class="logo">
<a href="#"><img src='../assets/images/logo.png'/></a>
</div>

<div id="wrap">


<!-- header begins -->
<div class="menu-wrap">
<?php

	if (!file_exists('/SpliceCom/WebManager/admin/update/container')) {
		header("Location: /manager/admin"); 
		exit();
	}
    
	unlink ('/SpliceCom/WebManager/admin/update/container');
	
	$tmp = NULL;
	if (file_exists('.tmp')) {
		$tmp = trim(file_get_contents('.tmp'));
		unlink ('.tmp');
	}
	
	$visionHTAdmin='';
	if (file_exists('/SpliceCom/config/adminhtpasswd')) {
		$adminConfig = file('/SpliceCom/config/adminhtpasswd');
		$adminUser = explode(':', $adminConfig[1]);
		$visionHTAdmin = $adminUser[0];
	}
		
	require('../assets/inc/header.php');
	
	$visionIP=NULL;
	$sr=ldap_list($ds,"cn=modules","(&(objectclass=module)(moduletype=20))", array('ipaddress'));
	$info = ldap_get_entries($ds, $sr); 
	if ($info['count']> 0) $visionIP = $info[0]['ipaddress'][0];
	
	
	
?>	
</div>
<!-- header ends -->

<!-- content begins -->
<div id="main">
<div class="wrapper">
<h3><span class="icon-list-numbered greyicon"></span> Update Passwords</h3><br/>


<form id='passwdupdate' name='passwdupdate'>
Use the form below to update the softPBX Manager and System Passwords.<br>
If Vision is installed it can be resynced to Manager by entering your Vision Administrator Credentials.<br><br>
Entering a New Vision Administrator Password will also update your Vision Credentials.<br>
<i>(<b>Please Note:</b> Vision will be restarted during this process)</i>
<br><br>
	<!-- #left -->
	<div class="colLeft">
	
	<h5>SoftPBX Passwords</h5>
	<div class='field password'>
		<label for="password_manager">Manager Password</label>
		<input type="password" name="password_manager" id="password_manager" autocomplete="off" tabindex="1" value=''>
		<span class='information passwordSpan'>USED TO GAIN ACCESS TO MANAGER</span>
	</div>
	
	<div class='field password'>
		<label for="password_maintainer">Maintainer Password</label>
		<input type="password" name="password_maintainer" id="password_maintainer" autocomplete="off" tabindex="2" value=''>
		<span class='information passwordSpan'>ACCESS TO THE ADMIN AND VOICEMAIL AREAS</span>
	</div>
	
	<div class='field password'>
		<label for="password_web">Web Password</label>
		<input type="password" name="password_web" id="password_web" autocomplete="off" tabindex="3" value=''>
		<span class='information passwordSpan'>ACCESS TO THE INTERNAL WEB SERVER</span>
	</div>
					
	<div class='field password'>
		<label for="password_calllogging">Call Logging Password</label>
		<input type="password" name="password_calllogging" id="password_calllogging" autocomplete="off" tabindex="4" value=''>
		<span class='information passwordSpan'>ACCESS TO CALL LOGGING INFORMATION</span>
	</div>
	
	</div> 
	<!-- #left -->
				
				
	<!-- #right -->
	<div class="colRight">
	
	<?php
	if (isset($visionIP)) {
	?>
	<h5>Vision Credentials</h5>
	
	<div class='field password'>
		<label for="newvisionpassword">New Vision Administrator Password</label>
		<input type="password" name="newvisionpassword" id="newvisionpassword" autocomplete="off" tabindex="7" value=''>
		<span class='information passwordSpan'>NEW VISION ADMINISTRATOR PASSWORD</span>
	</div>
	
	<div class='field password'>
		<label for="confpassword">Confirm Vision Administrator Password</label>
		<input type="password" name="confpassword" id="confpassword" autocomplete="off" tabindex="8" value=''>
		<span class='information passwordSpan'>CONFIRM VISION ADMINISTRATOR PASSWORD</span>
	</div>
	
	<?php 
	}
	?>
	
	<div class='update'>
		<input type='hidden' id='visionip' name='visionip' value='<?php echo $visionIP ?>'/>
		<input type="hidden" name="visionadmin" id="visionadmin" value='<?php echo $visionHTAdmin ?>'>
		<input type='hidden' id='tmpsession' name='tmpsession' value='<?php echo $tmp ?>'/>
		<input type='button' class='save' id='quit' value='Quit To Admin Portal'/>
		<input type='button' class='save' id='save' value='Save Passwords'/>
	</div>
	
	</div> 
	<!-- #right -->
	
</div>
</div>

<!--footer begins -->
<?php
	require('../assets/inc/footer.php');
?>
<!-- footer ends-->
</div>
</div>
</body>
</html>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/update/index.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>Update Passwords</title>
<meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
<meta http-equiv="Pragma" content="no-cache" />
<meta http-equiv="Expires" content="0" />
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<meta name="keywords" content="" />
<meta name="description" content="" />
<link href="../assets/css/styles.css" rel="stylesheet" type="text/css" media="screen" />
<link href="../assets/css/menu.css" media="screen" rel="stylesheet" type="text/css" />
<link href="../assets/css/buttons.css" rel="stylesheet" type="text/css">
<link href="update.css" media="screen" rel="stylesheet" type="text/css" />

<script src="../assets/js/jquery-min.js" type="text/javascript"></script>
<script src="../assets/js/jquery.noty.packaged.js" type="text/javascript"></script>
<script src="update.js" type="text/javascript"></script>

</head>
<body>
<div id="content">

<div class="logo">
<a href="#"><img src='../assets/images/logo.png'/></a>
</div>

<div id="wrap">


<!-- header begins -->
<div class="menu-wrap">
<?php

	if (!file_exists('/SpliceCom/WebManager/admin/update/container')) {
		header("Location: /manager/admin"); 
		exit();
	}
    
	unlink ('/SpliceCom/WebManager/admin/update/container');
	
	$tmp = NULL;
	if (file_exists('.tmp')) {
		$tmp = trim(file_get_contents('.tmp'));
		unlink ('.tmp');
	}
	
	$visionHTAdmin='';
	if (file_exists('/SpliceCom/config/adminhtpasswd')) {
		$adminConfig = file('/SpliceCom/config/adminhtpasswd');
		$adminUser = explode(':', $adminConfig[1]);
		$visionHTAdmin = $adminUser[0];
	}
		
	require('../assets/inc/header.php');
	
	$visionIP=NULL;
	$sr=ldap_list($ds,"cn=modules","(&(objectclass=module)(moduletype=20))", array('ipaddress'));
	$info = ldap_get_entries($ds, $sr); 
	if ($info['count']> 0) $visionIP = $info[0]['ipaddress'][0];
	
	
	
?>	
</div>
<!-- header ends -->

<!-- content begins -->
<div id="main">
<div class="wrapper">
<h3><span class="icon-list-numbered greyicon"></span> Update Passwords</h3><br/>


<form id='passwdupdate' name='passwdupdate'>
Use the form below to update the softPBX Manager and System Passwords.<br>
If Vision is installed it can be resynced to Manager by entering your Vision Administrator Credentials.<br><br>
Entering a New Vision Administrator Password will also update your Vision Credentials.<br>
<i>(<b>Please Note:</b> Vision will be restarted during this process)</i>

<br><br><b class='red'>Please Note:</b><br><span class='red'>Splicecom strongly recommends the use of strong passwords and login codes to minimise the possibility of brute force and dictionary attacks.</span><br><br>

	<!-- #left -->
	<div class="colLeft">
	
	<h5>SoftPBX Passwords</h5>
	<div class='field password'>
		<label for="password_manager">Manager Password</label>
		<input type="password" name="password_manager" id="password_manager" autocomplete="off" tabindex="1" value=''>
		<span class='information passwordSpan'>USED TO GAIN ACCESS TO MANAGER</span>
	</div>
	
	<div class='field password'>
		<label for="password_maintainer">Maintainer Password</label>
		<input type="password" name="password_maintainer" id="password_maintainer" autocomplete="off" tabindex="2" value=''>
		<span class='information passwordSpan'>ACCESS TO THE ADMIN AND VOICEMAIL AREAS</span>
	</div>
	
	<div class='field password'>
		<label for="password_web">Web Password</label>
		<input type="password" name="password_web" id="password_web" autocomplete="off" tabindex="3" value=''>
		<span class='information passwordSpan'>ACCESS TO THE INTERNAL WEB SERVER</span>
	</div>
					
	<div class='field password'>
		<label for="password_calllogging">Call Logging Password</label>
		<input type="password" name="password_calllogging" id="password_calllogging" autocomplete="off" tabindex="4" value=''>
		<span class='information passwordSpan'>ACCESS TO CALL LOGGING INFORMATION</span>
	</div>
	
	</div> 
	<!-- #left -->
				
				
	<!-- #right -->
	<div class="colRight">
	
	<?php
	if (isset($visionIP)) {
	?>
	<h5>Vision Credentials</h5>
	
	<div class='field password'>
		<label for="newvisionpassword">New Vision Administrator Password</label>
		<input type="password" name="newvisionpassword" id="newvisionpassword" autocomplete="off" tabindex="7" value=''>
		<span class='information passwordSpan'>NEW VISION ADMINISTRATOR PASSWORD</span>
	</div>
	
	<div class='field password'>
		<label for="confpassword">Confirm Vision Administrator Password</label>
		<input type="password" name="confpassword" id="confpassword" autocomplete="off" tabindex="8" value=''>
		<span class='information passwordSpan'>CONFIRM VISION ADMINISTRATOR PASSWORD</span>
	</div>
	
	<?php 
	}
	?>
	
	<div class='update'>
		<input type='hidden' id='visionip' name='visionip' value='<?php echo $visionIP ?>'/>
		<input type="hidden" name="visionadmin" id="visionadmin" value='<?php echo $visionHTAdmin ?>'>
		<input type='hidden' id='tmpsession' name='tmpsession' value='<?php echo $tmp ?>'/>
		<input type='button' class='save' id='quit' value='Quit To Admin Portal'/>
		<input type='button' class='save' id='save' value='Save Passwords'/>
	</div>
	
	</div> 
	<!-- #right -->
	
</div>
</div>

<!--footer begins -->
<?php
	require('../assets/inc/footer.php');
?>
<!-- footer ends-->
</div>
</div>
</body>
</html>
